@@ -4,7 +4,7 @@
 # Author: Dimitar Ivanov
 #
 set -e
-VER=1.1
+VER=1.1.1
 
 PROG=dish
 DIST_FILES='
@@ -20,6 +20,7 @@ SRCDIR=src
 UIDGID=0:0
 
 ### Functions
+#
 Usage () {
     cat << !
 
@@ -45,10 +46,10 @@ iamwho () {
    rm -f /tmp/.$$
 }
 
-### Functions
-
+### Process options and arguments
+#
 [ -z "$1" ] && set -- -h
-   # Process options and arguments
+
 while [ $# -gt 0 ]
 do
 case $1 in
@@ -84,7 +85,7 @@ done
 
 
 ### Do install/uninstall
-
+#
 [ $ALLED ] || { Usage ; exit ; }
 
 [ $QUIET ] || {
